<?php

/**
 * Used to display admin notices.
 *
 * @package    klaviyotoolkit
 * @subpackage klaviyotoolkit/includes
 * @author     Tribe Interactive <hello@madebytribe.com>
 */
class KT_Admin_Notices {
	
	public function register_hooks() {
		
		// Add action to display admin notices
		add_action( 'admin_notices', array( $this, 'display_admin_notices' ) );
		
		// Display welcome notice on KT settings page
		add_action( 'admin_notices', array( $this, 'display_welcome_notice' ) );
		
		// Display RetentionKit promo
		add_action( 'admin_notices', array( $this, 'display_rk_promo_notice' ) );
		
		// Display Coupon generator promo
		add_action( 'admin_notices', array( $this, 'display_cg_promo_notice' ) );
	
	}

	/**
	 * Display admin notices
	 */
	public function display_admin_notices() {
		
		$kt_license_status = get_option( 'klaviyo_edd_license_status' );

		if ( $kt_license_status !== 'valid' ) {
			$this->display_license_notice();
		}
	}

	/**
	 * Display license notice HTML
	 */
	private function display_license_notice() {
		?>
		<div class="notice notice-warning is-dismissible">
			<p><?php _e( '<strong>Klaviyo Toolkit</strong> - Your license is not active. Please <a href="' . admin_url( 'admin.php?page=wck-sub-events&tab=license' ) . '">activate your license</a> to enable the plugin features, receive updates and support.', 'klaviyo-toolkit' ); ?></p>
		</div>
		<?php
	}
	
	/**
	 * Display welcome notice
	 */
	public function display_welcome_notice() {
		
		global $pagenow;
		
		if ( $pagenow == 'admin.php' && isset($_GET['page']) && $_GET['page'] == 'wck-sub-events' ) {
			
			if ( ! PAnD::is_admin_notice_active( 'notice-kt-welcome-forever' ) ) {
				return;
			}
			
			$screen                          = get_current_screen();
			$kt_license_status               = get_option( 'klaviyo_edd_license_status' );
			$klaviyo_api_key                 = get_option( 'klaviyo_api_key' );
			$klaviyo_viewed_page             = get_option( 'klaviyo_viewed_page' );
			$klaviyo_wc_subscription_created = get_option( 'klaviyo_wc_subscription_created' );
			$klaviyo_abandoned_cart_coupon   = get_option( 'klaviyo_abandoned_cart_coupon' );
					
			if ( $screen->base == 'toplevel_page_wck-sub-events' ) { ?>
				<div data-dismissible="notice-kt-welcome-forever" class="notice is-dismissible kt-notice kt-welcome">
					<div class="kt-left"><img src="<?php echo plugin_dir_url( __DIR__ ) . 'admin/images/success.svg'; ?>" width="145" height="145" alt="Klaviyo Toolkit Welcome"></div>
					<div class="kt-right">
						<?php
						$current_user = wp_get_current_user();
						$first_name   = $current_user->first_name;
						?>
						<div class="welcome-heading">
							<?php
							if ( ! empty( $first_name ) ) {
								echo __( 'Welcome to the Klaviyo Toolkit, ', 'klaviyo-toolkit' ) . $first_name . '!';
							} else {
								echo __( 'Welcome to the Klaviyo Toolkit!', 'klaviyo-toolkit' );
							};
							?>
						</div>
						<p><?php echo esc_html( __( 'Thank you for purchasing the Klaviyo Toolkit! With this plugin you\'re unlocking new metric data and features to enhance your Klaviyo email marketing.', 'klaviyo-toolkit' ) ); ?></p>
						<h2><?php echo _e( 'Steps to get started:', 'klaviyo-toolkit' ); ?></h2>
						<ol class="kt-steps">
							<li class="completed">
								<?php echo _e( 'Install & activate the plugin', 'klaviyo-toolkit' ); ?>
								<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"><g id="check--check-form-validation-checkmark-success-add-addition-tick"><path id="Vector 2356 (Stroke)" fill="currentColor" fill-rule="evenodd" d="M23.914 6.914 8.5 22.33.086 13.914l2.828-2.828L8.5 16.672 21.086 4.086l2.828 2.828Z" clip-rule="evenodd"></path></g></svg>
							</li>
							<li class="<?php echo $kt_license_status == 'valid' ? 'completed' : ''; ?>">
								<a href="<?php echo esc_url( '/wp-admin/admin.php?page=wck-sub-events&tab=license' ); ?>">
								<?php echo _e( 'Activate your license', 'klaviyo-toolkit' ); ?>
								</a>
								<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"><g id="check--check-form-validation-checkmark-success-add-addition-tick"><path id="Vector 2356 (Stroke)" fill="currentColor" fill-rule="evenodd" d="M23.914 6.914 8.5 22.33.086 13.914l2.828-2.828L8.5 16.672 21.086 4.086l2.828 2.828Z" clip-rule="evenodd"></path></g></svg>
							</li>
							<li class="<?php echo !empty($klaviyo_api_key) ? 'completed' : ''; ?>">
								<a href="<?php echo esc_url( '/wp-admin/admin.php?page=wck-sub-events&tab=klaviyo-api' ); ?>">
								<?php echo _e( 'Add your Klaviyo API keys', 'klaviyo-toolkit' ); ?>
								</a>
								<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"><g id="check--check-form-validation-checkmark-success-add-addition-tick"><path id="Vector 2356 (Stroke)" fill="currentColor" fill-rule="evenodd" d="M23.914 6.914 8.5 22.33.086 13.914l2.828-2.828L8.5 16.672 21.086 4.086l2.828 2.828Z" clip-rule="evenodd"></path></g></svg>
							</li>
							<li class="<?php echo ($klaviyo_viewed_page !== 'disabled' || $klaviyo_wc_subscription_created !== 'disabled' || $klaviyo_abandoned_cart_coupon !== 'disabled') ? 'completed' : ''; ?>">
								<a href="<?php echo esc_url( '/wp-admin/admin.php?page=wck-sub-events&tab=settings' ); ?>">
								<?php echo _e( 'Configure your settings', 'klaviyo-toolkit' ); ?>
								</a>
								<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"><g id="check--check-form-validation-checkmark-success-add-addition-tick"><path id="Vector 2356 (Stroke)" fill="currentColor" fill-rule="evenodd" d="M23.914 6.914 8.5 22.33.086 13.914l2.828-2.828L8.5 16.672 21.086 4.086l2.828 2.828Z" clip-rule="evenodd"></path></g></svg>
							</li>
							<li class="<?php echo ! empty( $response_data ) ? 'completed' : ''; ?>">
								<a href="<?php echo esc_url( 'https://senja.io/p/tribe/r/zI4FVp' ); ?>" target="_blank">
									<?php echo _e( 'Leave a review', 'klaviyo-toolkit' ); ?>
								</a>
								<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"><g id="check--check-form-validation-checkmark-success-add-addition-tick"><path id="Vector 2356 (Stroke)" fill="currentColor" fill-rule="evenodd" d="M23.914 6.914 8.5 22.33.086 13.914l2.828-2.828L8.5 16.672 21.086 4.086l2.828 2.828Z" clip-rule="evenodd"></path></g></svg>
							</li>
						</ol>
					</div>
				</div>
			<?php
			}
		}
	}
	
	/**
	 * Display RK promo notice
	 */
	public function display_rk_promo_notice() {
		
		// Ensure WooCommerce is active
		if (!function_exists('WC')) return;
		
		// Get the current screen
		$screen = get_current_screen();
		
		// Check if RK is not active and if we're on the WooCommerce > Subscriptions page
		if ((  ! class_exists( 'rk' ) ) && ($screen->id === 'edit-shop_subscription')) {
			wp_enqueue_style('kt-admin-notice', plugin_dir_url( __DIR__ ) . 'admin/css/kt-admin-notices.css');
			
			if ( ! PAnD::is_admin_notice_active( 'notice-rk-promo-forever' ) ) {
				return;
			}
		?>
			<script type="text/javascript">
				jQuery(document).ready(function($) {
					// Parse numbers without commas
					var cancelledCount = parseInt($('.wc-cancelled span.count').text().replace(/\(|\)|,/g, "") || 0);
					var pendingCancelCount = parseInt($('.wc-pending-cancel span.count').text().replace(/\(|\)|,/g, "") || 0);
			
					// Function to add commas to numbers for display
					function numberWithCommas(x) {
						return x.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");
					}
				
					// Update the message first
					if (cancelledCount === 0 && pendingCancelCount === 0) {
						$('.dynamic-message').html("put a stop subscription cancellations!");
					} else if (cancelledCount === 0) {
						$('.dynamic-message').html("You have <span class='pending-cancel-count'></span> pending-cancels!");
					} else if (pendingCancelCount === 0) {
						$('.dynamic-message').html("You have <span class='cancel-count'></span> cancellations!");
					}
				
					// Then update the counts using formatted numbers with commas
					$('.cancel-count').html(numberWithCommas(cancelledCount));
					$('.pending-cancel-count').html(numberWithCommas(pendingCancelCount));
				});
			</script>
	
			<div data-dismissible="notice-rk-promo-forever" class="notice is-dismissible kt-notice rk-promo">
				<div class="kt-left"><img src="<?php echo plugin_dir_url( __DIR__ ) . 'admin/images/rk-cancel-promo.svg'; ?>" width="145" height="145" alt="kt Promo"></div>
				<div class="kt-right">
					<div class="welcome-heading">
						<span class="dynamic-message"><?php echo esc_html( __( 'You have ' ) ); ?> <span class="cancel-count"></span> <?php echo esc_html( __( 'cancellations and ' ) ); ?> <span class="pending-cancel-count"></span> <?php echo esc_html( __( 'pending-cancels!' ) ); ?></span>
					</div>
	
					<p class="rk-message">
						<?php echo esc_html( __( 'That\'s potential revenue slipping away. Let ' ) ); ?>
						<a href="<?php echo esc_url( 'https://www.getretentionkit.com/?utm_source=kt-plugin&amp;utm_medium=plugin&amp;utm_campaign=sub-promo-30' ); ?>"><?php echo esc_html( __( 'RetentionKit' ) ); ?></a>
						<?php echo esc_html( __( ' step in! We\'ll not only reveal why they\'re stepping back but also weave in offers that can transform those exits into profit boosts. In the subscription game, every comeback is a win for your bottom line. 💰' ) ); ?>
					</p>
					<p>
						<?php 
						echo wp_kses(
							__( 'Use code <strong>RKSAVE30</strong> to take <strong>30% off</strong> kt today and start saving your subscription revenue.' ),
							array(
								'strong' => array()
							)
						); 
						?>
					</p>
					<p class="kt-notice-ctas">
						<a class="button" href="<?php echo esc_url( 'https://www.getretentionkit.com/?utm_source=kt-plugin&amp;utm_medium=plugin&amp;utm_campaign=sub-promo-30' ); ?>"><?php echo esc_html( __( 'Enable Cancellation Protection' ) ); ?><img src="<?php echo plugin_dir_url( __DIR__ ) . 'admin/images/rk-arrow-right.svg'; ?>" width="20" height="20"></a>
					</p>
				</div>
			</div>
		<?php
		}
	}
	
	/**
	 * Coupon generator notice
	 */
	public function display_cg_promo_notice() {	

		// Check if Klaviyo is active & Coupon Generator is not
		if (( class_exists( 'WooCommerceKlaviyo' ) ) && ( ! class_exists( 'KlcouponsKlaviyo' ) )) {
			
			global $pagenow;
			
			if ( is_admin() && 'edit.php' == $pagenow && isset($_GET['post_type']) && $_GET['post_type'] == 'shop_coupon' ) {
				
				if ( ! PAnD::is_admin_notice_active( 'notice-cg-promo-forever' ) ) {
					return;
				}
				
				wp_enqueue_style('kt-admin-notice', plugin_dir_url( __DIR__ ) . 'admin/css/kt-admin-notices.css');
			
				?>
				<script type="text/javascript">
					jQuery(document).ready(function($) {
						$('.dismiss-this').on('click', function(e) {
							e.preventDefault(); 
							$('.rk-promo').hide(); 
						});
					});
				</script>
				<div data-dismissible="notice-cg-promo-forever" class="notice is-dismissible kt-notice rk-promo">
					<div class="kt-left"><img src="<?php echo plugin_dir_url( __DIR__ ) . 'admin/images/kc-promo.svg'; ?>" width="145" height="145" alt="Coupon Generator for Klaviyo Promo"></div>
					<div class="kt-right">
						<?php
						$current_user = wp_get_current_user();
						$first_name   = $current_user->first_name;
						?>
						<div class="welcome-heading">
							<?php 
								echo esc_html( __( 'Randomized coupons for Klaviyo are here' ) );
								if ( ! empty( $first_name ) ) {
									echo esc_html( sprintf( __( ', %s' ), $first_name ) );
								}
								echo esc_html( __( '!' ) ); 
							?>
						</div>
		
						<p class="rk-message">
							<?php echo esc_html( __( 'Dynamically generate unique, expiring WooCommerce coupons for your Klaviyo opt-in forms to add urgency to your emails and prevent coupon spam.' ) ); ?>
						</p>
						<p>
							<?php 
							echo wp_kses(
								__( 'Use code <strong>KCSAVE30</strong> to take <strong>30% off</strong> the Coupon Generator for Klaviyo plugin today.' ),
								array(
									'strong' => array()
								)
							); 
							?>
						</p>
						<p class="kt-notice-ctas">
							<a class="button" href="<?php echo esc_url( 'https://www.madebytribe.com/products/coupon-generator-for-klaviyo/?utm_source=kt-plugin&amp;utm_medium=plugin&amp;utm_campaign=notice-promo-30' ); ?>"><?php echo esc_html( __( 'Unlock Dynamic Klaviyo Coupons' ) ); ?><img src="<?php echo plugin_dir_url( __DIR__ ) . 'admin/images/rk-arrow-right.svg'; ?>" width="20" height="20"></a>
						</p>
					</div>
				</div>
		<?php
			}
		}
	}

}