<?php
/**
 * Plugin Name:       Klaviyo Toolkit
 * Plugin URI:        https://www.madebytribe.com
 * Description:       Send additional key metrics events from WooCommerce to Klaviyo, sync WooCommerce Subscription statuses, create abandoned cart coupons and more.
 * Version:           1.7
 * Author:            Tribe Interactive, LLC
 * Author URI:        https://www.madebytribe.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       klaviyo-toolkit
 * Domain Path:       /languages
 *
 * WC requires at least: 4.0
 * WC tested up to: 8.5.1
 *
 * ████████ ██████  ██ ██████  ███████ 
 *	  ██    ██   ██ ██ ██   ██ ██      
 *	  ██    ██████  ██ ██████  █████   
 *	  ██    ██   ██ ██ ██   ██ ██      
 *	  ██    ██   ██ ██ ██████  ███████ 
 *									 
 */

if ( ! defined( 'KLAVIYO_EDD_STORE_URL' ) ) {
	define( 'KLAVIYO_EDD_STORE_URL', 'https://www.madebytribe.com' );
}
if ( ! defined( 'KLAVIYO_EDD_ITEM_ID' ) ) {
	define( 'KLAVIYO_EDD_ITEM_ID', 16543 );
}
if ( ! defined( 'KLAVIYO_EDD_ITEM_NAME' ) ) {
	define( 'KLAVIYO_EDD_ITEM_NAME', 'Klaviyo Toolkit Plugin' );
}
if ( ! defined( 'KLAVIYO_TOOLKIT_VERSION' ) ) {
	define( 'KLAVIYO_TOOLKIT_VERSION', 'v1.7' );
}

/**
 * Register activation hook
 */
register_activation_hook( __FILE__, 'activate_klaviyo_toolkit' );

require_once( 'vendor/autoload.php' );

use Klaviyo\Client;

/**
 * Load notices
 */
require_once plugin_dir_path( __FILE__ ) . 'includes/class-kt-notices.php';

$kt_admin_notices = new KT_Admin_Notices();
$kt_admin_notices->register_hooks();

/**
 * Load dismissible notices library
 */
require  plugin_dir_path( __FILE__ ) . 'vendor/persist-admin-notices-dismissal/persist-admin-notices-dismissal.php';

add_action( 'admin_init', array( 'PAnD', 'init' ) );

/**
 * The code that runs during plugin activation.
 */
function activate_klaviyo_toolkit() {

	// Check if klaviyo WC subscription events plugin is available in the active plugin list
	if ( in_array( 'tribe-klaviyo-wc/tribe-klaviyo.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
		wp_die(
			sprintf(
				'<p>%1$s <strong>%2$s</strong> %3$s <strong>%4$s</strong> %5$s. <a href="%6$s">%7$s</a> %8$s</p>',
				esc_html( __( 'Please deactivate the', 'klaviyo-toolkit' ) ),
				esc_html( __( 'Tribe - Klaviyo WooCommerce Subscription Events', 'klaviyo-toolkit' ) ),
				esc_html( __( 'plugin before activating the', 'klaviyo-toolkit' ) ),
				esc_html( __( 'Klaviyo Toolkit', 'klaviyo-toolkit' ) ),
				esc_html( __( 'plugin', 'klaviyo-toolkit' ) ),
				esc_url( admin_url( '/plugins.php' ) ),
				esc_html( __( 'Click here', 'klaviyo-toolkit' ) ),
				esc_html( __( 'to return to Plugins page', 'klaviyo-toolkit' ) )
			)
		);
	}
}

/**
 * Load EDD custom updater if it doesn't already exist
 */
if ( ! class_exists( 'Klaviyo_Plugin_Updater' ) ) {
	include( dirname( __FILE__ ) . '/klaviyo-edd-plugin-updater.php' );
}

/**
 * Initialize the updater. Hooked into `admin_init` to work with the
 * wp_version_check cron job, which allows auto-updates.
 */
function klaviyo_toolkit_edd_sl_plugin_updater() {

	global $pagenow;
	// To support auto-updates, this needs to run during the wp_version_check cron job for privileged users.
	$doing_cron = defined( 'DOING_CRON' ) && DOING_CRON;
	if ( ! current_user_can( 'manage_options' ) && ! $doing_cron ) {
		return;
	}

	if ( $pagenow == 'update-core.php' || $pagenow == 'plugins.php' ) {
		// retrieve our license key from the DB
		$license_key = trim( get_option( 'klaviyo_edd_license_key' ) );

		// setup the updater
		$edd_updater = new Klaviyo_Plugin_Updater( KLAVIYO_EDD_STORE_URL, __FILE__,
			array(
				'version' => '1.7',                     // current version number
				'license' => $license_key,              // license key (used get_option above to retrieve from DB)
				'item_id' => KLAVIYO_EDD_ITEM_ID,       // ID of the product
				'author'  => 'Tribe Interactive, LLC',  // author of this plugin
				'beta'    => false,
			)
		);
	}
}

/**
 * Add action to initialize the updater
 */
add_action( 'init', 'klaviyo_toolkit_edd_sl_plugin_updater' );

/**
 * Check license status in admin license page
 */
function klaviyo_toolkit_edd_sl_license_check() {

	// Check EDD license on KT settings or license pages
	if ( isset( $_GET['page'] ) && ( 'wck-sub-events' === $_GET['page'] ) ) {
		// retrieve our license key from the DB
		$license_key = trim( get_option( 'klaviyo_edd_license_key' ) );

		// Yearly product response and license data
		$api_params = array(
			'edd_action' => 'check_license',
			'license'    => $license_key,
			'item_id'    => KLAVIYO_EDD_ITEM_ID,
			'url'        => home_url(),
		);

		// Call the custom API.
		$edd_item_response = wp_remote_post( KLAVIYO_EDD_STORE_URL, array( 'timeout' => 15, 'sslverify' => true, 'body' => $api_params ) );
		$license_data      = json_decode( wp_remote_retrieve_body( $edd_item_response ) );

		if ( 'valid' === $license_data->license ) {
			// this license is valid
			update_option( 'klaviyo_edd_license_status', 'valid' );
		} else {
			// this license is no longer valid
			update_option( 'klaviyo_edd_license_status', 'invalid' );
		}
	}
}

// Add action for cron hook to check license status
add_action( 'admin_init', 'klaviyo_toolkit_edd_sl_license_check' );

/**
 * Include TribeKlaviyo class
 */
include( plugin_dir_path( __FILE__ ) . 'includes/klaviyo.php' );

/**
 * WCKT_Hooks class
 */
class WCKT_Hooks {

	public function __construct() {
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_settings_link' ) );
		add_action( 'admin_init', array( $this, 'register_settings' ) );
		add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );

		// Add action to enqueue admin stylesheets
		add_action( 'admin_enqueue_scripts', array( $this, 'klaviyo_enqueue_styles' ) );

		// Add action to trigger a event after a customer purchases a subscription products
		add_action( 'woocommerce_subscription_payment_complete', array( $this, 'klaviyo_subscription_created' ), 10, 1 );

		// Add action to trigger a event when subscription status changes to pending cancel
		add_action( 'woocommerce_subscription_status_pending-cancel', array( $this, 'klaviyo_subscription_status_pending_cancel' ), 10, 1 );

		// Add action for viewed page event
		add_action( 'wp_footer', array( $this, 'klaviyo_viewed_events' ) );

		// Add action to add images to RSS feed
		add_action( 'rss2_item', array( $this, 'klaviyo_add_imgs_to_rss_feeds' ) );

		// Add action when WC subscription status changes
		add_action( 'woocommerce_subscription_status_updated', array( $this, 'klaviyo_subscription_status_changed' ), 10, 3 );

		// Add action for subscription renewal payment complete / failed
		add_action( 'woocommerce_subscription_renewal_payment_complete', array( $this, 'klaviyo_wc_subscription_renewal_payment' ), 10, 2 );
		add_action( 'woocommerce_subscription_renewal_payment_failed', array( $this, 'klaviyo_wc_subscription_renewal_payment' ), 10, 2 );

		// Add action to activate/deactivate license key
		add_action( 'wp_ajax_klaviyo_license_button', array( $this, 'klaviyo_license_options' ) );

		// Add filter to move email address field above name field
		add_filter( 'woocommerce_billing_fields', array( $this, 'klaviyo_move_checkout_email_above_name_fields' ), 10, 1 );

		// Add action to auto generate coupon code and update a customer profile field within Klaviyo
		add_action( 'wp', array( $this, 'klaviyo_coupon_code_and_loggedin_profile_update' ) );

		add_action( 'wp_enqueue_scripts', array( $this, 'klaviyo_enqueue_scripts' ) );

		// Add action to update klaviyo profile fields and auto generate coupon code
		add_action( 'wp_ajax_klaviyo_profile_update_generate_coupon', array( $this, 'klaviyo_profile_update_generate_coupon' ) );
		add_action( 'wp_ajax_nopriv_klaviyo_profile_update_generate_coupon', array( $this, 'klaviyo_profile_update_generate_coupon' ) );
		
		// Add order note event in Klaviyo when a new public order note is added
		add_action( 'woocommerce_new_customer_note', array( $this, 'klaviyo_customer_note_added' ) );
		
		// Trigger 'WC Subscription Switched' event when a subscription is switched
		add_action( 'woocommerce_subscriptions_switch_completed', array( $this, 'klaviyo_wc_subscription_switched' ), 10, 3 );
		
		// Declare HPOS compatibility		
		add_action( 'before_woocommerce_init', function() {
			if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
		} );
		
		// Show the subscription status export results
		add_action('wp_ajax_download_wc_subscriptions', array($this, 'ajax_download_wc_subscriptions'));
		add_action('wp_ajax_get_export_progress', array($this, 'ajax_get_export_progress'));
		add_action('wp_ajax_get_exported_file_url', array($this, 'ajax_get_exported_file_url'));
		add_action('wp_ajax_finish_export', array($this, 'finish_export_callback'));	

	}

	public function plugin_settings_link( $links ) {
		$url           = get_admin_url() . 'admin.php?page=wck-sub-events';
		$settings_link = '<a href="' . $url . '">' . __( 'Settings', 'klaviyo-toolkit' ) . '</a>';
		array_unshift( $links, $settings_link );

		return $links;
	}

	public function register_settings() {
		register_setting( 'wck-sub-events', 'wck-api-key' );
	}

	public function add_admin_menu() {
		add_menu_page(
			__( 'Klaviyo Toolkit', 'klaviyo-toolkit' ),
			__( 'Klaviyo Toolkit', 'klaviyo-toolkit' ),
			'manage_options',
			'wck-sub-events',
			array( $this, 'wck_menu' ),
			'dashicons-email-alt'
		);
	}

	public function wck_menu() {
		require plugin_dir_path( __FILE__ ) . 'admin/klaviyo-admin-display.php';
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function klaviyo_enqueue_styles() {

		if ( isset( $_GET['page'] ) ) {
			if ( 'wck-sub-events' === $_GET['page'] ) {
				
				// Load styles
				wp_enqueue_style( 'kt-admin-styles', plugin_dir_url( __FILE__ ) . 'admin/css/kt-admin.css' );
				wp_enqueue_style( 'kt-admin-notices', plugin_dir_url( __FILE__ ) . 'admin/css/kt-admin-notices.css' );
				
				// Load scripts
				wp_enqueue_script( 'kt-admin-js', plugin_dir_url( __FILE__ ) . 'admin/js/kt-admin.js', array( 'jquery' ), null, true );
				$params = array(
					'ajaxurl' => admin_url( 'admin-ajax.php' ),
				);
				wp_localize_script( 'kt-admin-js', 'klaviyoAdminAjax', $params );

			}
		}
	}

	/**
	 * Create a new event that triggers once a new subscription has been created.
	 *
	 * @param $subscription
	 *
	 * @throws \TribeKlaviyoException
	 */
	public function klaviyo_subscription_created( $subscription ) {

		$parent_order_id          = method_exists( $subscription, 'get_parent_id' ) ? $subscription->get_parent_id() : $subscription->order->id;
		$related_orders_ids_array = $subscription->get_related_orders();
		$last_related_order_id    = reset( $related_orders_ids_array );
		if ( $parent_order_id != $last_related_order_id ) {
			return;
		}

		$klaviyo_license_status = get_option( 'klaviyo_edd_license_status' );

		$subscription_items            = $subscription->get_items();
		$subscription_billing_interval = $subscription->get_billing_interval();
		$subscription_billing_period   = $subscription->get_billing_period();
		$sub_full_billing_int          = $subscription_billing_interval . ' ' . $subscription_billing_period;
		$klaviyo_client_obj            = new TribeKlaviyo( $this->get_api_key() );

		// WC subscription created event
		$klaviyo_wc_subscription_created = get_option( 'klaviyo_wc_subscription_created' );
		if ( 'enabled' === $klaviyo_wc_subscription_created && 'valid' === $klaviyo_license_status ) {

			$subscription_length = 0;
			foreach ( $subscription_items as $item ) {
				$is_trial = $this->is_trial( $subscription );

				$subscription_id       = $subscription->get_id();
				$sub_item_data         = $item->get_data();
				$sub_item_variation_id = $sub_item_data['variation_id'];
				$sub_item_id           = $sub_item_data['product_id'];
				$sub_product           = wc_get_product( $sub_item_id );
				$billing_period        = WC_Subscriptions_Product::get_period( $sub_product );
				$subscription_length   = WC_Subscriptions_Product::get_length( $sub_product );
				
				// If billing_period or subscription_length is empty and WCS_ATT_Order class exists
				if ( ( empty( $billing_period ) || empty( $subscription_length ) ) && class_exists( 'WCS_ATT_Order' ) ) {
					$subscription_scheme_key = WCS_ATT_Order::get_subscription_scheme( $item );
					if ( $subscription_scheme_key ) {
						$subscription_schemes = WCS_ATT_Product_Schemes::get_subscription_schemes( $sub_product );
						
						// If the subscription scheme exists in the fetched schemes
						if ( isset( $subscription_schemes[ $subscription_scheme_key ] ) ) {
							$subscription_scheme  = $subscription_schemes[ $subscription_scheme_key ];
							$billing_period       = $subscription_scheme->get_period();
							$subscription_length  = $subscription_scheme->get_interval();
						}
					}
				}
					
				$ranges                = wcs_get_subscription_ranges( $billing_period );
				$product_feat_img_url  = wp_get_attachment_url( get_post_thumbnail_id( $sub_item_id ) );
				
				// Fix for All Products for WC subscriptions
				if (isset($ranges[$subscription_length])) {
					$planExpiresAfter = $ranges[$subscription_length];
				} else {
					$planExpiresAfter = '';
				}
				
				// Initialize $planGifted to 'no'
				$planGifted = 'no';
				
				$subscription_email = $subscription->get_billing_email();
				
				// Check if the WC subscription gifting class exists
				if (class_exists('WCS_Gifting')) {
					$klaviyo_change_email_to_recipient = get_option('klaviyo_change_email_to_recipient');
					if ('enabled' === $klaviyo_change_email_to_recipient &&
						WCS_Gifting::is_gifted_subscription($subscription)) {
						$recipient_user_id  = WCS_Gifting::get_recipient_user($subscription);
						$recipient_user     = get_userdata($recipient_user_id);
						$subscription_email = $recipient_user->user_email;
						$planGifted         = 'yes';
					}
				}
				
				$wc_sub_created_array = array(
					'PlanName'            => $item->get_name(),
					'SubID'               => $subscription_id,
					'PlanID'              => $item->get_product_id(),
					'PlanTrial'           => $is_trial ? 'True' : 'False',
					'PlanTrialEndDate'    => $subscription->get_date( 'trial_end' ),
					'PlanExpirationDate'  => $subscription->get_date( 'schedule_end' ),
					'$value'              => $is_trial ? 0 : $subscription->get_total(),
					'PlanInterval'        => $sub_full_billing_int,
					'PlanNextPaymentDate' => $subscription->get_date_to_display( 'next_payment' ),
					'PlanExpiresAfter'    => $planExpiresAfter,
					'PlanGifted'          => $planGifted
				);

				// If variation id is not empty then add to event parameters
				if ( ! empty( $sub_item_variation_id ) ) {
					$wc_sub_created_array['PlanVariationID'] = $sub_item_variation_id;
				}

				if ( ! empty( $product_feat_img_url ) ) {
					$wc_sub_created_array['ProductImage'] = $product_feat_img_url;
				}
				
				// Add filter hook
				$wc_sub_created_array = apply_filters( 'tribe_klaviyo_sub_created_event', $wc_sub_created_array, $subscription );

				$klaviyo_client_obj->track(
					'WC Subscription Created',
					array( '$email' => $subscription_email ),
					$wc_sub_created_array
				);
				
				// Set the custom profile field for the plan status
				$product_key = 'wc-sub-product-' . $item->get_product_id();
				$custom_profile_param = array(
					$product_key => $subscription->get_status()
				);
				
				// Update the status field in Klaviyo
				$klaviyo_client_obj->identify(
					array_merge(
						array( '$email' => $subscription_email ),
						$custom_profile_param
					)
				);
			
			}
		}

		// Subscribed to Plan event
		$klaviyo_sub_events = get_option( 'klaviyo_subscription_events' );
		if ( 'enabled' === $klaviyo_sub_events && 'valid' === $klaviyo_license_status ) {

			foreach ( $subscription_items as $item ) {
				$is_trial = $this->is_trial( $subscription );

				$klaviyo_client_obj->track(
					'Subscribed to Plan',
					array( '$email' => $subscription->get_billing_email() ),
					array(
						'Plan'     => $item->get_name(),
						'PlanID'   => $item->get_product_id(),
						'PlanType' => $is_trial ? 'Trial' : 'Paid',
						'$value'   => $is_trial ? 0 : $subscription->get_total(),
					)
				);
			}
		}

	}

	private function get_api_key() {
		$wck_api_key = get_option( 'klaviyo_api_key' );

		return $wck_api_key;
	}

	private function is_trial( $subscription ) {
		return false != $subscription->get_date( 'trial_end' );
	}

	/**
	 * Subscription status changes to pending cancel.
	 *
	 * @param $subscription
	 *
	 * @throws \TribeKlaviyoException
	 */
	public function klaviyo_subscription_status_pending_cancel( $subscription ) {

		$klaviyo_license_status = get_option( 'klaviyo_edd_license_status' );

		$klaviyo_sub_events = get_option( 'klaviyo_subscription_events' );
		if ( 'enabled' === $klaviyo_sub_events && 'valid' === $klaviyo_license_status ) {

			$subscription_items = $subscription->get_items();
			$client             = new TribeKlaviyo( $this->get_api_key() );

			foreach ( $subscription_items as $item ) {
				$is_trial = $this->is_trial( $subscription );
				$response = $client->track(
					'Cancelled Plan',
					array( '$email' => $subscription->get_billing_email() ),
					array(
						'Plan'     => $item->get_name(),
						'PlanID'   => $item->get_product_id(),
						'PlanType' => $is_trial ? 'Trial' : 'Paid',
						'$value'   => $is_trial ? 0 : $subscription->get_total(),
					)
				);
			}
		}
	}

	/**
	 * Different viewed events
	 */
	public function klaviyo_viewed_events() {
		$wck_api_key = get_option( 'klaviyo_api_key' );
		?>
		<script type="application/javascript" async src="https://static.klaviyo.com/onsite/js/klaviyo.js?company_id=<?php echo $wck_api_key; ?>"></script>
		<?php
		global $post;
		$klaviyo_license_status = get_option( 'klaviyo_edd_license_status' );
		$klaviyo_viewed_page    = get_option( 'klaviyo_viewed_page' );
		$klaviyo_viewed_pro_cat = get_option( 'klaviyo_viewed_pro_cat' );
		$klaviyo_viewed_post    = get_option( 'klaviyo_viewed_post' );
		$klaviyo_searched_site  = get_option( 'klaviyo_searched_site' );

		// Viewed Page Event
		if ( 'enabled' === $klaviyo_viewed_page && is_page() && 'valid' === $klaviyo_license_status ) {
			$page_id        = $post->ID;
			$page_title     = get_the_title( $post );
			$page_permalink = get_the_permalink( $page_id );
			?>
			<script type="text/javascript">
							var _learnq = _learnq || [];
							_learnq.push( ['track', 'Viewed Page', {
								'PageName': '<?php echo $page_title; ?>',
								'PageID': '<?php echo $page_id; ?>',
								'URL': '<?php echo $page_permalink; ?>'
							}] );
			</script>
			<?php
		}

		// Viewed Product Category Event
		if ( 'enabled' === $klaviyo_viewed_pro_cat && is_product_category() && 'valid' === $klaviyo_license_status ) {
			$queried_object      = get_queried_object();
			$pro_cat_name        = $queried_object->name;
			$pro_cat_taxonomy_id = $queried_object->term_taxonomy_id;
			$cat_thumb_image_url = '';
			$cat_thumbnail_id    = get_term_meta( $pro_cat_taxonomy_id, 'thumbnail_id', true );
			if ( ! empty( $cat_thumbnail_id ) ) {
				$cat_thumb_image_url = wp_get_attachment_url( $cat_thumbnail_id );
			}
			$product_category_url = get_category_link( $pro_cat_taxonomy_id );
			?>
			<script type="text/javascript">
							var _learnq = _learnq || [];
							_learnq.push( ['track', 'Viewed Product Category', {
								'ProductCategoryName': '<?php echo $pro_cat_name; ?>',
								'ProductCategoryID': '<?php echo $pro_cat_taxonomy_id; ?>',
								'ImageURL': '<?php echo $cat_thumb_image_url; ?>',
								'URL': '<?php echo $product_category_url; ?>'
							}] );
			</script>
			<?php
		}

		// Viewed Post Event
		if ( 'enabled' === $klaviyo_viewed_post && is_single() && 'valid' === $klaviyo_license_status ) {
			$post_id         = $post->ID;
			$post_title      = get_the_title( $post );
			$post_categories = get_the_category( $post_id );
			$post_cats_array = array();
			if ( ! empty( $post_categories ) ) {
				foreach ( $post_categories as $post_category ) {
					$post_cats_array[] = $post_category->name;
				}
			}
			$post_cats_array = implode( ",", $post_cats_array );
			if ( has_post_thumbnail() ) {
				$post_featured_image_url = get_the_post_thumbnail_url( $post_id, 'full' );
			} else {
				$post_featured_image_url = '';
			}
			$post_permalink = get_the_permalink( $post_id );
			?>
			<script type="text/javascript">
							var _learnq = _learnq || [];
							_learnq.push( ['track', 'Viewed Post', {
								'PostName': '<?php echo $post_title; ?>',
								'PostID': '<?php echo $post_id; ?>',
								'PostCategory': '<?php echo $post_cats_array; ?>',
								'ImageURL': '<?php echo $post_featured_image_url; ?>',
								'URL': '<?php echo $post_permalink; ?>'
							}] );
			</script>
			<?php
		}

		// Searched Site Event
		if ( 'enabled' === $klaviyo_searched_site && is_search() && 'valid' === $klaviyo_license_status ) {
			$search_keyword       = filter_input( INPUT_GET, 's', FILTER_SANITIZE_SPECIAL_CHARS );
			$search_query         = new WP_Query( array( 's' => $search_keyword ) );
			$total_search_results = $search_query->found_posts;
			$search_results_url   = site_url() . '/?s=' . urlencode( $search_keyword );
			?>
			<script type="text/javascript">
							var _learnq = _learnq || [];
							_learnq.push( ['track', 'Searched Site', {
								'SearchTerm': '<?php echo $search_keyword; ?>',
								'ReturnedResults': <?php echo $total_search_results; ?>,
								'SearchResultsUrl': '<?php echo $search_results_url; ?>'
							}] );
			</script>
			<?php
		}
	}

	/**
	 * RSS feed featured image for Klaviyo
	 */
	public function klaviyo_add_imgs_to_rss_feeds() {

		$klaviyo_license_status  = get_option( 'klaviyo_edd_license_status' );
		$klaviyo_add_imgs_to_rss = get_option( 'klaviyo_add_imgs_to_rss' );
		if ( 'enabled' === $klaviyo_add_imgs_to_rss && 'valid' === $klaviyo_license_status ) {
			global $post;
			if ( has_post_thumbnail( $post->ID ) ) {
				$output            = '';
				$post_thumbnail_id = get_post_thumbnail_id( $post->ID );
				$thumbnail         = wp_get_attachment_image_src( $post_thumbnail_id, 'full' );
				$output            .= '<image>';
				$output            .= $thumbnail[0];
				$output            .= '</image>';
				echo $output;
			}
		}
	}

	/**
	 * WC subscription status changes
	 *
	 * @param $subscription
	 * @param $new_status
	 * @param $old_status
	 */
	public function klaviyo_subscription_status_changed( $subscription, $new_status, $old_status ) {
	
		// Proceed if old status is not pending
		if ( 'pending' !== $old_status ) {
		
			$klaviyo_license_status                = get_option( 'klaviyo_edd_license_status' );
			$klaviyo_wc_subscription_status_change = get_option( 'klaviyo_wc_subscription_status_change' );
		
			if ( 'enabled' === $klaviyo_wc_subscription_status_change && 'valid' === $klaviyo_license_status ) {
		
				$subscription_items = $subscription->get_items();
				$client             = new TribeKlaviyo( $this->get_api_key() );
		
				if ( ! empty( $subscription_items ) ) {
					foreach ( $subscription_items as $sub_item ) {
		
						$sub_item_data        = $sub_item->get_data();
						$subscription_plan    = $sub_item_data['name'];
						$subscription_plan_id = $sub_item_data['product_id'];
						$subscription_value   = $sub_item_data['total'];
						$product_feat_img_url = wp_get_attachment_url( get_post_thumbnail_id( $subscription_plan_id ) );
		
						$wc_status_changed_event_array = array(
							'WC Subscription Status Changed Value' => $subscription_value,
							'PlanName'                             => $subscription_plan,
							'PlanID'                               => $subscription_plan_id,
							'PlanValue'                            => $subscription_value,
							'PlanStatus'                           => $new_status
						);
		
						if ( 'cancelled' === $new_status || 'pending-cancel' === $new_status ) {
							$wc_status_changed_event_array['Subscription End Date'] = $subscription->get_date( 'end_date' );
						}
		
						if ( ! empty( $product_feat_img_url ) ) {
							$wc_status_changed_event_array['ProductImage'] = $product_feat_img_url;
						}
		
						// Add WC subscription status changed event to klaviyo
						$client->track(
							'WC Subscription Status Changed',
							array( '$email' => $subscription->get_billing_email() ),
							$wc_status_changed_event_array
						);
						
						// Set the custom profile field for the plan status
						$product_key = 'wc-sub-product-' . $sub_item->get_product_id();
						$custom_profile_param = array(
							$product_key => $subscription->get_status()
						);
						
						// Update the status field in Klaviyo
						$client->identify(
							array_merge(
								array( '$email' => $subscription->get_billing_email() ),
								$custom_profile_param
							)
						);
		
					}
				}
			}
		}
	}

	/**
	 * Subscription renewal payment complete.
	 *
	 * @param $subscription
	 * @param $last_order
	 */
	public function klaviyo_wc_subscription_renewal_payment( $subscription, $last_order ) {
		$klaviyo_license_status          = get_option( 'klaviyo_edd_license_status' );
		$klaviyo_wc_subscription_renewal = get_option( 'klaviyo_wc_subscription_renewal' );

		if ( 'enabled' === $klaviyo_wc_subscription_renewal && 'valid' === $klaviyo_license_status ) {

			$subscription_items        = $subscription->get_items();
			$client                    = new TribeKlaviyo( $this->get_api_key() );
			$last_renewal_order_status = $last_order->get_status();

			$subscription_renewal_status = 'Success';
			if ( 'failed' === $last_renewal_order_status ) {
				$subscription_renewal_status = 'Fail';
			}
			$subscription_billing_interval = $subscription->get_billing_interval();
			$subscription_billing_period   = $subscription->get_billing_period();
			$sub_full_billing_int          = $subscription_billing_interval . ' ' . $subscription_billing_period;
			$subscription_id               = $subscription->get_id(); // Real plan ID

			if ( ! empty( $subscription_items ) ) {
				foreach ( $subscription_items as $sub_item ) {

					$sub_item_data        = $sub_item->get_data();
					$subscription_plan    = $sub_item_data['name'];
					$subscription_plan_id = $sub_item_data['product_id']; // Product ID
					$subscription_value   = $sub_item_data['total'];
					$product_feat_img_url = wp_get_attachment_url( get_post_thumbnail_id( $subscription_plan_id ) );
					
					// Get the renewal count
					$renewal_count = $this->get_total_subscription_renewals($subscription_id);
					
					$wc_sub_renewal_array = array(
						'WC Subscription Renewal Value' => $subscription_value,
						'SubID'                         => $subscription_id,
						'PlanName'                      => $subscription_plan,
						'PlanID'                        => $subscription_plan_id,
						'PlanValue'                     => $subscription_value,
						'PlanRenewalStatus'             => $subscription_renewal_status,
						'PlanInterval'                  => $sub_full_billing_int,
						'SubTotalOrders'               => $renewal_count,
						'NextPaymentDate'               => $subscription->get_date_to_display( 'next_payment' ),
					);

					if ( ! empty( $product_feat_img_url ) ) {
						$wc_sub_renewal_array['ProductImage'] = $product_feat_img_url;
					}

					// Add WC subscription renewal event to klaviyo
					$client->track(
						'WC Subscription Renewal',
						array( '$email' => $subscription->get_billing_email() ),
						$wc_sub_renewal_array
					);
				}
			}
		}
	}

	/**
	 * Check license activate/deactivate functionality
	 */
	public function klaviyo_license_options() {

		$button_name = ! empty( $_POST['button_name'] ) ? $_POST['button_name'] : '';

		// listen for our activate button to be clicked
		if ( 'klaviyo_edd_license_activate' === $button_name ) {

			// retrieve the license from the database
			$klaviyo_license_key = trim( get_option( 'klaviyo_edd_license_key' ) );

			// data to send in our API request
			$api_params = array(
				'edd_action' => 'activate_license',
				'license'    => $klaviyo_license_key,
				'item_id'    => KLAVIYO_EDD_ITEM_ID, // The ID of the item in EDD
				'url'        => home_url(),
			);

			// Call the custom API.
			$response     = wp_remote_post( KLAVIYO_EDD_STORE_URL, array( 'timeout' => 15, 'sslverify' => true, 'body' => $api_params ) );
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			// make sure the response came back okay
			if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {
				$message = ( is_wp_error( $response ) && ! empty( $response->get_error_message() ) ) ? $response->get_error_message() : __( 'An error occurred, please try again.', 'klaviyo-toolkit' );
			} else {
				if ( false === $license_data->success ) {
					switch ( $license_data->error ) {
						case 'expired' :
							$message = sprintf(
								__( 'Your license key expired on %s.' ),
								date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
							);
							break;
						case 'revoked' :
							$message = __( 'Your license key has been disabled.' );
							break;
						case 'missing' :
							$message = __( 'Invalid license.' );
							break;
						case 'invalid' :
						case 'site_inactive' :
							$message = __( 'Your license is not active for this URL.' );
							break;
						case 'item_name_mismatch' :
							$message = sprintf( __( 'This appears to be an invalid license key for %s.' ), EDD_SAMPLE_ITEM_NAME );
							break;
						case 'no_activations_left':
							$message = __( 'Your license key has reached its activation limit.' );
							break;
						default :
							$message = __( 'An error occurred, please try again.' );
							break;
					}
				}
			}

			// Check if anything passed on a message constituting a failure
			if ( ! empty( $message ) ) {
				$base_url = admin_url( 'admin.php?page=wck-sub-events&tab=license' );
				// Redirect url are returned
				$data = array(
					'redirect_url'  => $base_url,
					'sl_activation' => 'false',
					'message'       => $message,
				);
				wp_send_json( $data );
			}

			// $license_data->license will be either "valid" or "invalid"
			update_option( 'klaviyo_edd_license_status', $license_data->license );

			// Redirect url are returned
			$data = array(
				'redirect_url'  => admin_url( 'admin.php?page=wck-sub-events&tab=license' ),
				'sl_activation' => 'true',
				'message'       => __( 'License successfully activated', 'klaviyo-toolkit' ),
			);
			wp_send_json( $data );

		} else if ( 'klaviyo_edd_license_deactivate' === $button_name ) {

			// retrieve the license from the database
			$klaviyo_license_key = trim( get_option( 'klaviyo_edd_license_key' ) );

			// data to send in our API request
			$api_params = array(
				'edd_action' => 'deactivate_license',
				'license'    => $klaviyo_license_key,
				'item_name'  => urlencode( KLAVIYO_EDD_ITEM_NAME ), // the name of our product in EDD
				'url'        => home_url(),
			);

			// Call the custom API.
			$response = wp_remote_post( KLAVIYO_EDD_STORE_URL, array( 'timeout' => 15, 'sslverify' => true, 'body' => $api_params ) );

			// make sure the response came back okay
			if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {
				if ( is_wp_error( $response ) ) {
					$message = $response->get_error_message();
				} else {
					$message = __( 'An error occurred, please try again.' );
				}
				$base_url = admin_url( 'admin.php?page=wck-sub-events&tab=license' );
				// Redirect url are returned
				$data = array(
					'redirect_url'  => $base_url,
					'sl_activation' => 'false',
					'message'       => $message,
				);
				wp_send_json( $data );
			}

			// decode the license data
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			// $license_data->license will be either "deactivated" or "failed"
			if ( $license_data->license == 'deactivated' || $license_data->license == 'failed' ) {
				delete_option( 'klaviyo_edd_license_status' );
			}

			// Redirect url are returned
			$data = array(
				'redirect_url'  => admin_url( 'admin.php?page=wck-sub-events&tab=license' ),
				'sl_activation' => 'true',
				'message'       => __( 'License deactivated', 'klaviyo-toolkit' ),
			);
			wp_send_json( $data );
		}
		wp_die();
	}

	/**
	 * Move email address field on checkout to above the name fields
	 *
	 * @param $address_fields
	 *
	 * @return mixed
	 */
	public function klaviyo_move_checkout_email_above_name_fields( $address_fields ) {

		$klaviyo_license_status          = get_option( 'klaviyo_edd_license_status' );
		$klaviyo_email_above_name_fields = get_option( 'klaviyo_email_above_name_fields' );

		if ( 'enabled' === $klaviyo_email_above_name_fields && 'valid' === $klaviyo_license_status ) {
			$address_fields['billing_email']['priority'] = 5;
		}

		return $address_fields;
	}

	/**
	 * Auto generate coupon code and update a customer profile field within Klaviyo
	 */
	public function klaviyo_coupon_code_and_loggedin_profile_update() {
		if ( is_checkout() && is_user_logged_in() ) {

			$klaviyo_abandoned_cart_coupon = get_option( 'klaviyo_abandoned_cart_coupon' );
			if ( 'enabled' !== $klaviyo_abandoned_cart_coupon ) {
				return;
			}

			$current_user       = wp_get_current_user();
			$current_username   = $current_user->user_login;
			$current_user_email = $current_user->user_email;

			// Auto generate coupon code
			$this->klaviyo_auto_generate_coupon_code( $current_username, $current_user_email );

			// Update the customer profile in Klaviyo
			$this->klaviyo_update_customer_profile( $current_user_email );
		}
	}

	/**
	 * Auto generate coupon code on the checkout page.
	 *
	 * @param $username
	 * @param $user_email
	 */
	public function klaviyo_auto_generate_coupon_code( $username, $user_email ) {

		$klaviyo_coupon_amount = get_option( 'klaviyo_coupon_amount' );
		$klaviyo_coupon_amount = ! empty( $klaviyo_coupon_amount ) ? $klaviyo_coupon_amount : 0;
		$klaviyo_coupon_prefix = get_option( 'klaviyo_coupon_prefix' );
		$klaviyo_coupon_prefix = ! empty( $klaviyo_coupon_prefix ) ? $klaviyo_coupon_prefix : 'kt';

		// Generate a non existing coupon code name
		if ( is_user_logged_in() ) {
			$coupon_code = $klaviyo_coupon_prefix . '-promo-' . $username . '-' . $klaviyo_coupon_amount;
		} else {
			$coupon_code = $klaviyo_coupon_prefix . '-' . $user_email . '-' . $klaviyo_coupon_amount;
		}

		if ( wc_get_coupon_id_by_code( $coupon_code ) ) {
			return;
		}
		// Get an empty instance of the WC_Coupon Object
		$coupon = new WC_Coupon();
		
		$klaviyo_coupon_type            = get_option( 'klaviyo_coupon_type' );
		$klaviyo_coupon_expiration      = get_option( 'klaviyo_coupon_expiration' );
		$klaviyo_coupon_expiration_days = ! empty( $klaviyo_coupon_expiration ) ? $klaviyo_coupon_expiration : 0;
		
		// Only set expiration date if klaviyo_coupon_expiration_days is greater than 0
		if ( $klaviyo_coupon_expiration_days > 0 ) {
			$current_date                   = date( 'Y-m-d', current_time( 'timestamp', 0 ) );
			$klaviyo_coupon_expiration_date = date( 'Y-m-d', strtotime( $current_date . ' + ' . $klaviyo_coupon_expiration_days . ' days' ) );
			$coupon->set_date_expires( $klaviyo_coupon_expiration_date );
		}
		
		$klaviyo_coupon_used_with_other = get_option( 'klaviyo_coupon_used_with_other' );
		$klaviyo_coupon_free_shipping   = get_option( 'klaviyo_coupon_free_shipping' );

		if ( 'percentage' === $klaviyo_coupon_type ) {
			$discount_type = 'percent';
		} else {
			$discount_type = 'fixed_cart';
		}
		
		// Set the necessary coupon data (since WC 3+)
		$coupon->set_code( $coupon_code );
		$coupon->set_amount( $klaviyo_coupon_amount );
		$coupon->set_email_restrictions( array( $user_email ) );
		$coupon->set_usage_limit( 1 );
		$coupon->set_individual_use( true );
		$coupon->set_description( 'Klaviyo Toolkit Plugin Coupon Generation' );
		$coupon->set_discount_type( $discount_type );
		// Create, publish and save coupon (data)
		$coupon->save();

		// Update individual coupon meta option
		$coupon_id = wc_get_coupon_id_by_code( $coupon_code );
		update_post_meta( $coupon_id, 'individual_use', ( 'no' === $klaviyo_coupon_used_with_other ) ? 'yes' : 'no' );
		update_post_meta( $coupon_id, 'free_shipping', ( 'yes' === $klaviyo_coupon_free_shipping ) ? 'yes' : 'no' ); // Update Allow free shipping checkbox
	}

	/**
	 * Update Klaviyo user profile.
	 *
	 * @param $user_email
	 */
	public function klaviyo_update_customer_profile( $user_email ) {

		$secret_api_key = get_option( 'klaviyo_private_api_key' );
		if ( empty( $secret_api_key ) ) {
			return;
		}

		$client = new Client( $secret_api_key, $num_retries = 3, $wait_seconds = 3 );

		$clientProfile = $client->Profiles->getProfileId( $user_email );

		$clientProfileID = $clientProfile['id'];

		$kt_coupon_amount      = get_option( 'klaviyo_coupon_amount' );
		$klaviyo_coupon_prefix = get_option( 'klaviyo_coupon_prefix' );
		$klaviyo_coupon_prefix = ! empty( $klaviyo_coupon_prefix ) ? $klaviyo_coupon_prefix : 'kt';

		// Generate a non existing coupon code name
		if ( is_user_logged_in() ) {
			$current_user     = wp_get_current_user();
			$current_username = $current_user->user_login;
			$coupon_code      = $klaviyo_coupon_prefix . '-promo-' . $current_username . '-' . $kt_coupon_amount;
		} else {
			$coupon_code = $klaviyo_coupon_prefix . '-' . $user_email . '-' . $kt_coupon_amount;
		}

		$coupon                = new WC_Coupon( $coupon_code );
		$klaviyo_coupon_amount = $coupon->get_amount();

		$expiry_date = $coupon->get_date_expires();
		$expiry_time = $coupon->get_meta( 'expiry_time' ); // Coupon custom field
		
		$body_params = array(
			'ac-coupon'        => $coupon_code,
			'ac-coupon-amount' => $klaviyo_coupon_amount,
		);
		
		if ( $expiry_date instanceof WC_DateTime ) {
			$klaviyo_coupon_expiration      = new WC_DateTime( $expiry_date->date( 'Y-m-d' ) . ' ' . $expiry_time );
			$klaviyo_coupon_expiration_date = $klaviyo_coupon_expiration->format( 'm/d/Y' );
		
			$body_params['ac-coupon-expiration'] = $klaviyo_coupon_expiration_date;
		}
		
		$client->Profiles->updateProfile( $clientProfileID, $body_params );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 */
	public function klaviyo_enqueue_scripts() {
		wp_enqueue_script( 'klaviyo-public-js', plugin_dir_url( __FILE__ ) . 'public/js/klaviyo-public.js', array( 'jquery' ), null, true );
		$params = array(
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
		);
		wp_localize_script( 'klaviyo-public-js', 'klaviyoPublicAjax', $params );
	}

	public function klaviyo_profile_update_generate_coupon() {
		$billing_email                 = filter_input( INPUT_POST, 'billing_email', FILTER_SANITIZE_SPECIAL_CHARS );
		$klaviyo_abandoned_cart_coupon = get_option( 'klaviyo_abandoned_cart_coupon' );

		if ( ! empty( $billing_email ) && is_email( $billing_email ) &&
		     'enabled' === $klaviyo_abandoned_cart_coupon ) {

			$current_user     = wp_get_current_user();
			$current_username = ! empty( $current_user ) ? $current_user->user_login : '';

			$this->klaviyo_auto_generate_coupon_code( $current_username, $billing_email );

			// Update the customer profile in Klaviyo
			$this->klaviyo_update_customer_profile( $billing_email );

			wp_send_json_success();
		}

		wp_die();
	}
	
	/**
	 * Send order note event to Klaviyo
	 *
	 */	
	public function klaviyo_customer_note_added( $args ) {
		$klaviyo_license_status          = get_option( 'klaviyo_edd_license_status' );
		$klaviyo_order_note = get_option( 'klaviyo_order_note' );
		
		if ( 'enabled' === $klaviyo_order_note && 'valid' === $klaviyo_license_status ) {
			
			$order = wc_get_order( $args['order_id'] );
			$customer_email = $order->get_billing_email();
		
			$client   = new TribeKlaviyo( $this->get_api_key() );
			$response = $client->track(
				'Order Note Added',
				array( '$email' => $customer_email ),
				array(
					'OrderID' => $args['order_id'],
					'Note'    => $args['customer_note']
				)
			);
		}
	}
	
	public function klaviyo_wc_subscription_switched( $order_id ) {
		
		$klaviyo_license_status = get_option( 'klaviyo_edd_license_status' );
		$klaviyo_wc_subscription_switched = get_option( 'klaviyo_wc_subscription_switched' );
		
		if ( 'enabled' === $klaviyo_wc_subscription_switched && 'valid' === $klaviyo_license_status ) {
			
			$order = wc_get_order( $order_id );
						
			$subscriptions = wcs_get_subscriptions_for_order( $order_id );
			$subscription = end($subscriptions);
	
			$customer_email = $subscription->get_billing_email();
	
			$subscription_id = $subscription->get_id();
			$value = $subscription->get_total();
	
			$billing_interval = $subscription->get_billing_interval();
			$billing_period = $subscription->get_billing_period();
			$plan_interval = $billing_interval . ' ' . $billing_period;
	
			$next_payment_date = $subscription->get_date('next_payment');
			$subscription_link = wc_get_endpoint_url( 'view-subscription', $subscription_id, wc_get_page_permalink( 'myaccount' ) );
	
			$new_order_items = $order->get_items();
			$new_order_item = reset($new_order_items);
			$new_product = $new_order_item->get_product();
			$new_plan_name = $new_product->get_name();
			$new_product_image = wp_get_attachment_image_src($new_product->get_image_id(), 'full')[0] ?? '';
			$new_product_link = get_permalink($new_product->get_id());
			$new_var_name = $this->get_variation_name( $new_product, $new_order_item );
	
			$related_orders = $subscription->get_related_orders( 'ids', array('parent', 'renewal', 'switch') );
	
			array_pop($related_orders); 
			$orderedIds = array_values($related_orders); // convert associative array to indexed array	
			$previous_order_index = 1;			
			$previous_order_id = $orderedIds[$previous_order_index]; // get second last value
	
	
			$previous_order = wc_get_order( $previous_order_id );
			
			$old_plan_name = '';
			$old_var_name = '';
			$old_product_image = '';
			$old_product_link = '';
			
			if ($previous_order && is_a($previous_order, 'WC_Order')) {
				$previous_items = $previous_order->get_items();
				$previous_item = end($previous_items);
		
				$previous_product = $previous_item->get_product();
		
				$old_plan_name = $previous_product->get_name();
				$old_product_image = wp_get_attachment_image_src($previous_product->get_image_id(), 'full')[0] ?? '';
				$old_product_link = get_permalink($previous_product->get_id());
				$old_var_name = $this->get_variation_name( $previous_product, $previous_item );
			} else {
				error_log("Order with ID: $previous_order_id not found or is not a valid WC_Order");
			}
	
			$client = new TribeKlaviyo( $this->get_api_key() );
			$response = $client->track(
				'WC Subscription Switched',
				array( '$email' => $customer_email ),
				array(
					'SubID'               => $subscription_id,
					'SubInterval'         => $plan_interval,
					'SubNextPaymentDate'  => $next_payment_date,
					'SubManageLink'       => $subscription_link,
					'OldProductName'      => $old_plan_name,
					'OldProductVarName'   => $old_var_name,
					'OldProductImage'     => $old_product_image,					
					'OldProductLink'      => $old_product_link,
					'NewProductName'      => $new_plan_name,
					'NewProductVarName'   => $new_var_name,
					'NewProductImage'     => $new_product_image,
					'NewProductLink'      => $new_product_link,
					'$value'              => $value
				)
			);
		}
	}
	
	public function get_variation_name($product, $item) {
		if ($product->is_type('variation')) {
	
			// Fetch metadata from the order item
			$item_data = $item->get_meta_data();
	
			$exclude_keys = [ // Keys to exclude from the output
				'_switched_subscription_sign_up_fee_prorated',
				'_switched_subscription_price_prorated',
				'_cart_item_key_subscription_switch'
			];
	
			$variation_data = [];
			foreach ($item_data as $data) {
				if (strpos($data->key, 'attribute_') === 0) {
					$variation_data[str_replace('attribute_', '', $data->key)] = $data->value;
				} elseif (strpos($data->key, 'pa_') === 0) {
					$variation_data[str_replace('pa_', '', $data->key)] = $data->value;
				} elseif (!in_array($data->key, $exclude_keys)) {
					// For keys that do not have prefixes and are not in the exclude list
					if (strpos($data->key, '-') !== false) {  // If the key contains a hyphen
						$exploded_data = explode('-', $data->key);
						$variation_data[end($exploded_data)] = $data->value; // Use only the part after the hyphen
					} else {
						$variation_data[$data->key] = $data->value;  // Directly use the key
					}
				}
			}
	
			// Construct variation name
			$var_name = '';
			foreach ($variation_data as $attribute => $value) {
				$var_name .= ucfirst($attribute) . ': ' . $value . ', ';
			}
	
			return rtrim($var_name, ', ');
	
		}
	
		return '';
	}
	
	/**
	 * Get total subscription renewals
	 *
	 * @param $subscription_id
	 */
	private function get_total_subscription_renewals($subscription_id) {
		// Ensure WooCommerce Subscriptions is active
		if (!function_exists('wcs_get_subscription')) {
			return;
		}
	
		// Get the subscription object
		$subscription = wcs_get_subscription($subscription_id);
	
		// Check if the subscription exists
		if (!$subscription) {
			return 'Subscription not found.';
		}
	
		// Get related orders for the subscription
		$related_orders_ids = $subscription->get_related_orders('ids', 'any');
	
		// Count the number of related orders
		$total_renewals = count($related_orders_ids);
	
		return $total_renewals;
	}
	
	/**
	 * Generate the subscription status csv export file
	 */
	private $batch_size = 500;  // Define the batch size as a class property
	 
	private function initialize_export() {
		error_log('Starting CSV generation...');
		
		// Set the filename transient here
		$upload_dir = wp_upload_dir();
		$kt_exports_dir = trailingslashit($upload_dir['basedir']) . 'kt-exports/';
		if (!file_exists($kt_exports_dir)) {
			wp_mkdir_p($kt_exports_dir);  // Create directory if it doesn't exist
		}
		$file_name = $kt_exports_dir . 'wc-sub-status-export-' . current_time('YmdHis') . '.csv';
		set_transient('kt_export_filename', $file_name, 10 * MINUTE_IN_SECONDS);
		error_log('Transient kt_export_filename set: ' . $file_name);
		
		$this->set_all_subscription_product_ids();
		$this->write_headers_to_csv();  // Add this line here to write the headers
		
		if (false === get_transient('subscription_export_progress')) {
			set_transient('subscription_export_progress', 0, 10 * MINUTE_IN_SECONDS);
		}
	}
	
	/**
	 * Function to fetch all subscriptions
	 */
	private function fetch_subscriptions($offset = 0) {
	
		$data = [];
		$processed_in_batch = 0;  // Number of subscriptions processed in this batch.
	
		// Fetch subscriptions for the current batch.
		$args = [
			'subscriptions_per_page' => $this->batch_size,
			'offset' => $offset
		];
	
		$subscriptions = wcs_get_subscriptions($args);
		error_log('Fetched ' . count($subscriptions) . ' subscriptions at offset ' . $offset);
	
		foreach ($subscriptions as $subscription) {
			$email = $subscription->get_billing_email();
			$items = $subscription->get_items();
	
			if (!isset($data[$email])) {
				$data[$email] = [];
			}
	
			foreach ($items as $item) {
				if (!is_object($item) || !method_exists($item, 'get_product_id')) {
					error_log('Subscription with ID ' . $subscription->get_id() . ' has an invalid item. Skipping.');
					continue;  // Continue to next iteration of loop
				}
	
				$product_id = 'wc-sub-product-' . $item->get_product_id();
				$subscription_status = $subscription->get_status();
	
				$data[$email][$product_id] = $subscription_status;
			}
	
			// Increment the counter for processed subscriptions in this batch.
			$processed_in_batch++;
		}
	
		// Write this batch's data to the CSV.
		$this->write_batch_to_csv($data);
	
		// Return the number of subscriptions processed in this batch.
		return $processed_in_batch;
	}
	
	/**
	 * Handle ajax request to download subscriptions CSV
	 */
	public function ajax_download_wc_subscriptions() {
				
		// Check for the offset in the request.
		$offset = isset($_POST['offset']) ? intval($_POST['offset']) : 0;
	
		// If offset is 0, it means this is the start of the export, so initialize.
		if ($offset === 0) {
			$this->initialize_export();
		}
	
		// Fetch Subscriptions and write them directly to the CSV
		$batch_size = $this->fetch_subscriptions($offset);  // Assume fetch_subscriptions returns the number of subscriptions processed in the batch.
	
		// Calculate the progress.
		$query = new WP_Query([
			'post_type' => 'shop_subscription',
			'post_status' => 'any',
			'fields' => 'ids',
			'posts_per_page' => -1
		]);
		$total_subscriptions = $query->found_posts;
	
		$processed_subscriptions = $offset + $batch_size;
		$progress = min(100, round(($processed_subscriptions / $total_subscriptions) * 100));
	
		// Determine if more batches are needed.
		$hasMore = ($processed_subscriptions < $total_subscriptions);
	
		// Respond with progress and offset data.
		$response = array(
			'hasMore' => $hasMore,
			'nextOffset' => $offset + $this->batch_size,
			'progress' => $progress
		);
	
		// If all subscriptions are processed, add the file URL to the response.
		if (!$hasMore) {
			$file_url = $this->convert_file_name_to_url($this->get_csv_filename());
			$response['file'] = $file_url;
			delete_transient('subscription_export_progress'); // Clear the progress once done
		}
		
		header('Content-Type: application/json');
	
		echo json_encode($response);
		wp_die();
	}
	
	/**
	 * Function to get the CSV filename
	 */
	private function get_csv_filename() {
		$file_name = get_transient('kt_export_filename');
		if (!$file_name) {
			error_log('Error: Filename transient not set!');
			return false;
		}
		return $file_name;
	}
	
	/**
	 * Function to convert the filename to a URL
	 */
	private function convert_file_name_to_url($file_name) {
		// Convert the file name to its respective URL for downloading
		$upload_dir = wp_upload_dir();
		$base_url = trailingslashit($upload_dir['baseurl']);
		$relative_path = str_replace($upload_dir['basedir'], '', $file_name); // Get the relative path of the file
		$file_url = $base_url . ltrim($relative_path, '/');
		return $file_url;
	}
	
	/**
	 * Show ajax export progress on the front-end
	 */
	public function ajax_get_export_progress() {
		$progress = get_transient('subscription_export_progress');
		echo is_numeric($progress) ? $progress : 0;
		error_log('Progress Transient Value: ' . $progress);
		wp_die();
	}
	
	/**
	 * Get the exported URL
	 */
	public function ajax_get_exported_file_url() {
		
		error_log("Getting exported file URL...");
		
		set_transient('exported_file_url', $this->convert_file_name_to_url($this->get_csv_filename()), 10 * MINUTE_IN_SECONDS);
		
		// Assuming you store the file URL in a transient or option after the export
		$file_url = get_transient('exported_file_url');
	
		if ($file_url) {
			wp_send_json_success(['file' => $file_url]);
		} else {
			wp_send_json_error(['message' => 'File not found.']);
		}
	}
	
	/**
	 * Function to write CSV
	 */
	private function write_batch_to_csv($data) {
		$file_name = $this->get_csv_filename();
		$file_handle = fopen($file_name, 'a');  // Append mode
	
		$all_product_ids = array_keys(get_transient('all_subscription_product_ids') ?: []);
	
		foreach ($data as $email => $subscriptions) {
			$row = [$email];
	
			foreach ($all_product_ids as $product_id) {
				$row[] = $subscriptions[$product_id] ?? '';  // Use null coalescing operator
			}
	
			fputcsv($file_handle, $row);
		}
	
		fclose($file_handle);
	}
	
	private function write_headers_to_csv() {
		$file_name = $this->get_csv_filename();
		
		// Check if the file is empty before writing headers
		if (!file_exists($file_name) || filesize($file_name) == 0) {
			$file_handle = fopen($file_name, 'a');
			
			$headers = ['Email'];  // Start with the email header
			$all_product_ids = array_keys(get_transient('all_subscription_product_ids') ?: []);
			foreach ($all_product_ids as $product_id) {
				$headers[] = $product_id;  // Add all product IDs as headers
			}
			
			fputcsv($file_handle, $headers);
			fclose($file_handle);
		}
	}
	
	function finish_export_callback() {
		delete_transient('kt_export_filename');
		wp_send_json_success();
	}
	
	/**
	 * Function to set product IDs in export file
	 */
	private function set_all_subscription_product_ids() {
		global $wpdb;
	
		error_log('set_all_subscription_product_ids: start');
	
		$existing_data = get_transient('all_subscription_product_ids');
		if ($existing_data) {
			error_log('Existing transient data found. Skipping product ID gathering.');
			return;  // Exit the function early if we already have the data
		}
	
		// Fetch unique product IDs from order items table where order type is 'shop_subscription'
		$query = "
			SELECT DISTINCT order_item_meta.meta_value as product_id
			FROM {$wpdb->prefix}woocommerce_order_items as order_items
			INNER JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta
			ON order_items.order_item_id = order_item_meta.order_item_id
			WHERE order_item_meta.meta_key = '_product_id'
			AND order_items.order_id IN (SELECT ID FROM {$wpdb->posts} WHERE post_type = 'shop_subscription')
		";
	
		$results = $wpdb->get_col($query);
		$all_product_ids = [];
	
		foreach ($results as $product_id) {
			$all_product_ids['wc-sub-product-' . $product_id] = true;
		}
	
		set_transient('all_subscription_product_ids', $all_product_ids, 10 * MINUTE_IN_SECONDS);
	
		error_log('set_all_subscription_product_ids: end');
	}

}

$GLOBALS['WCKT_Hooks'] = new WCKT_Hooks();
